@@ -4,13 +4,16 @@ use crate::CliResult;
 use serde::Deserialize;
 
 static USAGE: &str = r#"
-Read CSV data with special quoting rules.
+Read CSV data with special quoting and line-skipping rules.
 
 Generally, all qsv commands support basic options like specifying the delimiter
 used in CSV data. This does not cover all possible types of CSV data. For
 example, some CSV files don't use '"' for quotes or use different escaping
 styles.
 
+Also, CSVs that are technically malformed with preamble lines can be converted
+into a format qsv can handle with the --skip-lines option.
+
 Usage:
     qsv input [options] [<input>]
 
@@ -19,6 +22,7 @@ input options:
     --escape <arg>         The escape character to use. When not specified,
                            quotes are escaped by doubling them.
     --no-quoting           Disable quoting completely.
+    --skip-lines <arg>     The number of lines to skip.
 
 Common options:
     -h, --help             Display this message
@@ -35,6 +39,7 @@ struct Args {
     flag_quote: Delimiter,
     flag_escape: Option<Delimiter>,
     flag_no_quoting: bool,
+    flag_skip_lines: Option<usize>,
 }
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
@@ -55,6 +60,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut rdr = rconfig.reader()?;
     let mut wtr = wconfig.writer()?;
     let mut row = csv::ByteRecord::new();
+    if let Some(skip_lines) = args.flag_skip_lines {
+        for _i in 1..=skip_lines {
+            rdr.read_byte_record(&mut row)?;
+        }
+    }
     while rdr.read_byte_record(&mut row)? {
         wtr.write_record(&row)?;
     }
