@@ -90,8 +90,8 @@ mod util;
 static USAGE: &str = concat!(
     "
 Usage:
-    qsv <command> [<args>...]
-    qsv [options]
+    qsvlite <command> [<args>...]
+    qsvlite [options]
 
 Options:
     --list               List all commands available.
@@ -118,9 +118,8 @@ fn main() {
     util::init_logger();
 
     let now = Instant::now();
-
+    let mut qsv_args: String = env::args().skip(1).collect::<Vec<_>>().join(" ");
     if log_enabled!(Level::Info) {
-        let qsv_args: String = env::args().skip(1).collect::<Vec<_>>().join(" ");
         info!("START: {qsv_args}");
     }
 
@@ -145,7 +144,7 @@ fn main() {
     match args.arg_command {
         None => {
             werr!(concat!(
-                "qsv is a suite of CSV command line utilities.
+                "qsvlite is a suite of CSV command line utilities.
 
 Please choose one of the following commands:",
                 command_list!()
@@ -156,7 +155,16 @@ Please choose one of the following commands:",
         Some(cmd) => match cmd.run() {
             Ok(()) => {
                 if log_enabled!(Level::Info) {
-                    info!("END elapsed: {}", now.elapsed().as_secs_f32());
+                    let ellipsis = if qsv_args.len() > 15 {
+                        qsv_args.truncate(15);
+                        "..."
+                    } else {
+                        ""
+                    };
+                    info!(
+                        "END \"{qsv_args}{ellipsis}\" elapsed: {}",
+                        now.elapsed().as_secs_f32()
+                    );
                 }
                 process::exit(0);
             }
